@@ -1,6 +1,7 @@
 /*
  * Copyright 2014 Martin Gräßlin <mgraesslin@kde.org>
  * Copyright 2015 Marco Martin <mart@kde.org>
+ * Copyright 2020 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,6 +36,8 @@ namespace KWayland
         class PlasmaWindowManagement;
         class PlasmaShell;
         class Registry;
+        class ShadowManager;
+        class ShmPool;
         class SlideManager;
     }
 }
@@ -52,9 +55,11 @@ public:
     KWayland::Client::BlurManager *waylandBlurManager();
     KWayland::Client::ContrastManager *waylandContrastManager();
     KWayland::Client::SlideManager *waylandSlideManager();
+    KWayland::Client::ShadowManager *waylandShadowManager();
     KWayland::Client::Compositor *waylandCompositor() const;
     KWayland::Client::PlasmaWindowManagement *plasmaWindowManagement();
     KWayland::Client::PlasmaShell *waylandPlasmaShell();
+    KWayland::Client::ShmPool *waylandShmPool();
 
 private:
     QPointer<KWayland::Client::ConnectionThread> m_waylandConnection;
@@ -63,8 +68,10 @@ private:
     QPointer<KWayland::Client::BlurManager> m_waylandBlurManager;
     QPointer<KWayland::Client::ContrastManager> m_waylandContrastManager;
     QPointer<KWayland::Client::SlideManager> m_waylandSlideManager;
+    QPointer<KWayland::Client::ShadowManager> m_waylandShadowManager;
     QPointer<KWayland::Client::PlasmaWindowManagement> m_wm;
     QPointer<KWayland::Client::PlasmaShell> m_waylandPlasmaShell;
+    QPointer<KWayland::Client::ShmPool> m_waylandShmPool;
 };
 
 #endif
